import {useState,useEffect,useMemo}from'react';import {Subject}from'rxjs';/**
 * Returns a functiont that will trigger an error on the next render,
 * which can be caught by an ErrorBoundary higher up in the component tree.
 */
function useError() {
  const [error, setError] = useState();
  if (error) {
    throw error;
  }
  return setError;
}
/**
 * React hook to get the latest value of an Observable.
 * Will return `undefined` if the Observable didn't emit yet.
 * If the Observable errors, will throw an error that can be caught with `try`/`cactch` or with an React error boundary.
 * The Observable is subscribed on the first render and unsubscribed on unmount or whenever it changes (wrap it in `useMemo()`) to make sure it is not resubscribed on every render.
 *
 * @param observable The Observable to subscribe to. If this is the return value of a function, you should use `useMemo()` to make sure it is not resubscribed on every render.
 * @throws If the Observable pipeline errors.
 */
function useObservable(observable) {
  const [error, setError] = useState();
  const [currentValue, setCurrentValue] = useState();
  useEffect(() => {
    setCurrentValue(undefined);
    const subscription = observable.subscribe({
      next: setCurrentValue,
      error: setError
    });
    return () => subscription.unsubscribe();
  }, [observable]);
  if (error) {
    throw error;
  }
  return currentValue;
}
function useEventObservable(transform) {
  const events = useMemo(() => new Subject(), []);
  const observable = useMemo(() => events.pipe(transform), [events, transform]);
  const nextEvent = useMemo(() => events.next.bind(events), [events]);
  const value = useObservable(observable);
  return [nextEvent, value];
}export{useError,useEventObservable,useObservable};//# sourceMappingURL=useObservable.js.map
